%%% File `disertasi.cls' ditujukan untuk menulis disertasi
%%% menggunakan LaTeX untuk program Doktor
%%% di Institut Teknologi Bandung,
%%% berdasarkan pedoman penulisan disertasi ITB tahun 2008
%%%
%%% File ini berisi makro-makro LaTeX untuk memudahkan
%%% penulisan disertasi dengan format sesuai ketentuan SPS ITB.
%%% Kelas utama yang digunakan adalah `book.cls', dan dengan
%%% demikian semua perintah (untuk penyesuaian) yang berlaku
%%% di kelas `book', bila perlu, masih dapat digunakan.
%%%
%%% Any comments, suggestions, additions, corrections, modifications
%%% to this file are welcome.
%%% We rely on your feedback for improving this tool.
%%% <yunusm@matematika.its.ac.id>

\ProvidesClass{disertasi}[08/08/08 v1.01]
\NeedsTeXFormat{LaTeX2e}
%\LoadClass[a4paper,12pt,twoside,openright,final]{book} % Ini untuk bolak-balik
\LoadClass[a4paper,12pt,oneside,final]{book}   % Ini yang tidak bolak-balik
\RequirePackage{calc}
\RequirePackage{nohyperref}
\RequirePackage[hang]{caption}
\RequirePackage{minitoc}
%\RequirePackage[tight,french]{fancynum}
%\usepackage[labelsep=space]{caption}  % Tambahan buat caption

%----------------------------------------------------------
\DeclareRobustCommand{\Judul}[1]{%
    \newcommand{\@judul}{#1}%
    \title{\@judul}}%
\DeclareRobustCommand{\Nama}[1]{%
   \newcommand{\@nama}{#1}%
   \author{\@nama}}%
\DeclareRobustCommand{\Nim}[1]{%
   \DeclareRobustCommand{\@nim}{#1}}%
\newcommand\@progstudi{Program Studi Matematika}
\DeclareRobustCommand\ProgStudi[1]{%
   \renewcommand\@progstudi{#1}}%
\newcommand\@tahun{2008}
\DeclareRobustCommand\Tahun[1]{%
   \renewcommand\@tahun{#1}}%
\newcommand\@pbbsatu{}
\newcommand\@pbbdua{}
\newcommand\@pbbtiga{}
\newcommand\@pbbempat{}
\DeclareRobustCommand\Pembimbing[4]{%
   \renewcommand{\@pbbsatu}{#1}%
   \renewcommand{\@pbbdua}{#2}%
   \renewcommand{\@pbbtiga}{#3}%
   \renewcommand{\@pbbempat}{#4}}%
\newcommand\@tanggalsetuju{\today}
\DeclareRobustCommand\TanggalDisetujui[1]{%
   \renewcommand\@tanggalsetuju{#1}}%
\DeclareRobustCommand{\JudulEng}[1]{%
    \newcommand{\@judulEng}{#1}}%

%%%----atur spasi -----------------------------------------------------
\newcommand{\displayskipstretch}{\baselinestretch}

\newcommand{\setstretch}[1]{%
  \def\baselinestretch{#1}%
  \@currsize
}

\newcommand{\SetSinglespace}[1]{%
  \def\setspace@singlespace{#1}%
}
\SetSinglespace{1}
\newcommand{\singlespacing}{%
  \setstretch {\setspace@singlespace}%
  \vskip \baselineskip  %
}
\newcommand{\onehalfspacing}{%
  \setstretch{1.25}%  default
  \ifcase \@ptsize \relax % 10pt
    %\setstretch {1.44}%
    \setstretch {1.3}%
  \or % 11pt
    %\setstretch {1.423}%
    \setstretch {1.275}%
  \or % 12pt
    %\setstretch {1.441}%
    \setstretch {1.31}%
  \fi
}
\newcommand{\doublespacing}{%
  \setstretch {1.667}%  default
  \ifcase \@ptsize \relax % 10pt
    \setstretch {1.667}%
  \or % 11pt
    \setstretch {1.618}%
  \or % 12pt
    \setstretch {1.655}%
  \fi
}

\def\@setsize#1#2#3#4{%
  \@nomath#1%
  \let\@currsize#1%
  \baselineskip #2%
  \baselineskip \baselinestretch\baselineskip
  \parskip \baselinestretch\parskip
  \setbox\strutbox \hbox{%
    \vrule height.7\baselineskip
           depth.3\baselineskip
           width\z@}%
  \skip\footins \baselinestretch\skip\footins
  \normalbaselineskip\baselineskip#3#4}

\let\latex@xfloat=\@xfloat
\def\@xfloat #1[#2]{%
  \latex@xfloat #1[#2]%
  \def\baselinestretch{\setspace@singlespace}%
  \normalsize
}

\long\def\@footnotetext#1{%
  \insert\footins{%
    \def\baselinestretch {\setspace@singlespace}%
    \reset@font\footnotesize
    \interlinepenalty\interfootnotelinepenalty
    \splittopskip\footnotesep
    \splitmaxdepth \dp\strutbox \floatingpenalty \@MM
    \hsize\columnwidth
    \@parboxrestore
    \protected@edef\@currentlabel{%
      \csname p@footnote\endcsname\@thefnmark
    }%
    \color@begingroup
      \@makefntext{%
        \rule\z@\footnotesep\ignorespaces#1\@finalstrut\strutbox}%
    \color@endgroup}}
\everydisplay\expandafter{%
  \the\everydisplay
  \abovedisplayskip \displayskipstretch\abovedisplayskip
  \belowdisplayskip \displayskipstretch\belowdisplayskip
  \abovedisplayshortskip \displayskipstretch\abovedisplayshortskip
  \belowdisplayshortskip \displayskipstretch\belowdisplayshortskip
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%  Halaman Judul
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{times}
\newcommand\HalamanJudul{%---------------------------
  \null
  \pagenumbering{roman}
  \thispagestyle{empty}
  %\enlargethispage{1.75\baselineskip}               -==============JARAK BAGIAN BAWAH SAMPUL SETELAH TAHUN
  %\vskip 7.5\p@
  \singlespacing
  \begin{center}%
    %{\large\bfseries{\@judul}\par}%
    \vskip -1.2cm
    {\large\bfseries{\MakeUppercase{\@judul}}\par}%
    %\vfill
    \vskip 3.2cm
    {\large\bfseries TESIS} \par
    {%\lineskip .5em%
    \normalsize\bfseries
    Karya tulis sebagai salah satu syarat \\
    untuk memperoleh gelar Magister dari \\
    Institut Teknologi Bandung} \par
    %\vskip 3.5em%
    %\vfill
    \vskip 2.5cm
    {\normalsize\bfseries Oleh} \\ 
    {\large\bfseries\MakeUppercase{\@nama}\\ 
     NIM: \@nim \\ 
     (\@progstudi)} %\par
    \vskip 2.4cm%
    \includegraphics[height=3.6cm]{LogoITB}\par
    \vskip 2.4cm%     %Untuk mengubah jarak antara logo ITB dan ITB
    {\large\bfseries
     INSTITUT TEKNOLOGI BANDUNG \\
     \vskip 0.23em    
     \@tahun}
  \end{center}
}
\newcommand{\garis}{\rule{4.5cm}{0.4pt}}
%\newcommand{\garis2}{\rule{4.3cm}{0.4pt}
%\newcommand{\garis3}{\rule{4.0cm}{0.4pt}}
\RequirePackage{tabularx}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%  HALAMAN PENGESAHAN
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newcommand\HalamanPengesahan{%-------------------------
  \newpage
  \addcontentsline{toc}{chapter}{HALAMAN PENGESAHAN}
  \thispagestyle{plain}
  \singlespacing
\bigskip
  \begin{center}%
    {\large\bfseries{\@judul}\par}%
     %{\large\bfseries{\MakeUppercase{\@judul}}\par}%
    \vskip1.8cm
    %\vfill
   {\normalsize\normalfont Oleh} \\
\vskip0.4cm
    {\large\bfseries 
     \@nama \\ [1ex]
 \vskip0.1cm
     NIM:\ \@nim \\
   % \vskip-0.4cm
     (\@progstudi)} \par  %\\[1ex]}
\vskip0.3cm
   {\normalsize\normalfont Institut Teknologi Bandung} \\ %\par
  \vskip2cm
    %\vfill
    Menyetujui \\  %\par
   %\vskip-0.4cm
   Pembimbing \par
   \vskip.5cm
   Tanggal \@tanggalsetuju \par
    
    \ifthenelse{\equal{\@pbbempat}{}\OR\equal{\@pbbempat}{ }}%
    {\ifthenelse{\equal{\@pbbtiga}{}\OR\equal{\@pbbtiga}{ }}%
       {\ifthenelse{\equal{\@pbbdua}{}\OR\equal{\@pbbdua}{ }}{}%
          {\SetujuDua}%
       }%
       {\SetujuTiga}%
    }
    {\SetujuEmpat}
    \vfill
  \end{center}
}
\newcommand\SetujuTiga{%
    \vskip1.5cm
    Ketua \par
    \vskip2.5cm
    \garis\\[.5ex]
    (\@pbbsatu) \par
    \vskip 2.0cm
    \begin{tabularx}{\textwidth}{cXc}
    Anggota  && Anggota \\
   \rule{0pt}{2.5cm}
    \garis && \garis\\[.5ex]
    (\@pbbdua)&&(\@pbbtiga)
    \end{tabularx}}
\newcommand\SetujuDua{%
    \vskip 1.5cm
   \vskip 1.5cm
    \begin{tabularx}{\textwidth}{cXc}
    Ketua && Anggota \\
    \rule{0pt}{2.0cm}\\
    \garis && \garis\\[.5ex]
    (\@pbbsatu)&&(\@pbbdua)
    \end{tabularx}}
\newcommand\SetujuEmpat{%
   \vskip1cm
    \begin{tabularx}{\textwidth}{cXc}
    Ketua && Anggota \\
    \rule{0pt}{.5cm}\\
    \garis && \garis\\[.5ex]
    (\@pbbsatu)&&(\@pbbdua)\\[7ex]
    Anggota && Anggota \\
    \rule{0pt}{2.5cm}\\
    \garis && \garis\\[.5ex]
   (\@pbbtiga)&&(\@pbbempat)
    \end{tabularx}}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%% Pedoman Penggunaan Disertasi
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newcommand{\pedoman}{PEDOMAN PENGGUNAAN TESIS}
\newpage
\newenvironment{penggunaan}{%-----------------------------
\newpage\addcontentsline{toc}{chapter}{\pedoman}
\onehalfspacing
\begin{center}
    {\large \bfseries \pedoman}
\end{center}
\vskip1em
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\renewcommand\thechapter {\@Roman\c@chapter}
\renewcommand\thesection {\thechapter.\@arabic\c@section}
\renewcommand\thesubsection   {\thesection.\@arabic\c@subsection}
\renewcommand\thesubsubsection{\thesubsection .\@arabic\c@subsubsection}
\renewcommand\theparagraph    {\thesubsubsection.\@arabic\c@paragraph}
\renewcommand\thesubparagraph {\theparagraph.\@arabic\c@subparagraph}
\renewcommand\theequation{\@Roman\c@chapter.\@arabic\c@equation}


\newcommand{\katakunci}[1]{%
\bigskip
\begin{tabularx}{\textwidth}{@{}lX@{}}
\rm{Kata kunci:} & \textrm{#1}
\end{tabularx}}

\newcommand{\keywords}[1]{%
\bigskip
\begin{tabularx}{\textwidth}{@{}lX@{}}
\it{Keywords:} & \textit{#1}
\end{tabularx}}

\newenvironment{Abstrak}{%-------------------------------
  \clearpage
  \singlespacing
  \pagenumbering{roman}
  \setcounter{page}{1}
  \date{\today}
  \addcontentsline{toc}{chapter}{ABSTRAK}
%  \null                   POSISI ABSTRAK
%  \vskip 2em%             POSISI ABSTRAK
  \begin{center}%
    \large\bfseries %\vskip -1.5cm
    {ABSTRAK} \\ \par
  \vskip 12pt % 2ex%
    {\large\bfseries{\@judul}} \\ \par
    \vskip 12pt  % 2ex%
    {\normalfont\normalsize Oleh} \\ %\par
    {\bfseries
    {\large \@nama%
    \\
    NIM: \@nim \\
    (\@progstudi)}} \\ \par
    \vskip 36pt
    %\par
    %\vskip1em
  \end{center}%
  \par
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% ABSTRACT
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newenvironment{Abstract}{%------------------------------
  \clearpage
  \singlespacing
  \addcontentsline{toc}{chapter}{\emph{ABSTRACT}}
%  \null                      POSISI ABSTRACT
%  \vskip 2em%                POSISI ABSTRACT
  \begin{center}%
    {\large\bfseries %\vskip -1.5cm 
    {\emph{ABSTRACT}}} \\   %\par
    \vskip 18pt%  %2ex
    {\large\bfseries{\@judulEng}} \\ \par % \par}%
    \vskip 12pt  %2ex%
    {\normalfont\normalsize \emph by} \\ %\par%
    {\bfseries \large \@nama%
    \\
    NIM: \@nim\\
({\emph{Magister Program in Groundwater Engineering}})} \\ \par
    %\par
    \vskip 36pt   %1em
  \end{center}%
  \par
}

\newenvironment{Ringkasan}{%-------------------------------
  \clearpage
  \singlespacing
  \pagenumbering{roman}
  \setcounter{page}{2}
  \date{\today}
%  \addcontentsline{toc}{chapter}{Abstrak}
  \addcontentsline{toc}{chapter}{RINGKASAN}
%  \null                   POSISI ABSTRAK
%  \vskip 2em%             POSISI ABSTRAK
  \begin{center}%
    \normalsize\bfseries RINGKASAN \par
    \vskip 2ex%
    {\large\bfseries{\@judul} \par}%
    \vskip 2ex%
    {\normalfont\normalsize Oleh} \par%
    \@nama%
    \par
    NIM: \@nim
    \par
    \vskip1em
  \end{center}%
  \par
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% PERSEMBAHAN
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newenvironment{persembahan}{%-----------------------------
 \newpage
    \pagestyle{plain}
 \addcontentsline{toc}{chapter}{HALAMAN PERUNTUKAN}
\thispagestyle{plain}
 \singlespacing
% \setcounter{page}{7}
 \null
 \vfill   %agar posisi ditengah
 \begin{center}
    \itshape}{%
 \end{center}
 \vfill    %agar posisi ditengah
 \null
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% KATA PENGANTAR
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


\newcommand{\trmkasih}{KATA PENGANTAR}
\newpage
\clearpage
    \pagestyle{plain}
\newenvironment{terimakasih}{%-----------------------------
  \newpage\addcontentsline{toc}{chapter}{\trmkasih}
  \onehalfspacing
  \begin{center}
    {\large\bfseries \trmkasih}
  \end{center}
\vskip1em
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% DAFTAR PUBLIKASI
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newcommand{\dftrpublikasi}{DAFTAR PUBLIKASI}
\clearpage
    \pagestyle{plain}
\newenvironment{daftarpublikasi}{%-----------------------------
  \newpage\addcontentsline{toc}{chapter}{\dftrpublikasi}
  \onehalfspacing
  \begin{center}
    {\large\bfseries \dftrpublikasi}
  \end{center}
\vskip1em
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% RIWAYAT HIDUP
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newenvironment{riwayathidup}{%----------------------------
 \newpage
 \addcontentsline{toc}{chapter}{RIWAYAT HIDUP} % PENULIS}
 \onehalfspacing
 \begin{center}
    \large\bfseries RIWAYAT HIDUP \end{center}
\vskip1em

}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage[hmargin={4cm,3cm},vmargin={3cm,3cm},footskip=1.8cm]{geometry}
\RequirePackage{graphicx}
\RequirePackage{parskip}
\RequirePackage{amssymb}
\RequirePackage{amsmath}
\RequirePackage{amsthm}
\RequirePackage{amsfonts}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Pengaturan Jenis Font
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%---menentukan jenis font yang digunakan--------
\RequirePackage{times}
\RequirePackage{mathrsfs}
\RequirePackage[scaled=.90]{helvet}
%%---mengatur jarak dalam list -----------
\RequirePackage{enumitem}
\setlist{labelindent=\parindent,itemsep=-2ex,%
         leftmargin=*,topsep=-2ex}
%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%% Daftar Isi
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\newcommand{\DaftarIsi}{%---------------------
    \clearpage
    \pagestyle{plain}
    \singlespacing
    \addcontentsline{toc}{chapter}{DAFTAR ISI}
    \tableofcontents}
    
%%%================================TAMBAHAN UNTUK GENERATE LIST OF APPENDICES=====================%%%%
\newcommand\listofappendices{\@starttoc{loa}}
\newcommand\l@appendix{chapter}


\newcommand{\DaftarLampiran}{%--------------------
    \clearpage
    \pagestyle{plain}
    \singlespacing
    \addcontentsline{toc}{chapter}{DAFTAR LAMPIRAN}
%    \listofappendixes
    }
%\renewcommand*\l@appendix{\@dottedtocline{1}{1.5em}{7.35em}}

\newcommand{\DaftarGambar}{%----------------------
    \clearpage
    \singlespacing
    \pagestyle{plain}
    \singlespacing
    \addcontentsline{toc}{chapter}{DAFTAR GAMBAR}
    \listoffigures}
\renewcommand*\l@figure{\@dottedtocline{1}{1.5em}{6.35em}}
     

\newcommand{\DaftarTabel}{%----------------------
    \clearpage
    \singlespacing
    \addcontentsline{toc}{chapter}{DAFTAR TABEL}
    \listoftables}
\renewcommand*\l@table{\@dottedtocline{1}{1.5em}{5em}}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
\RequirePackage{ifthen}
\RequirePackage[refpage]{nomencl}
\renewcommand{\nomname}{\vskip -1.2cm{DAFTAR LAMBANG}}
%\renewcommand{\nomname}{\vskip -1.2cm{DAFTAR SINGKATAN DAN LAMBANG}}
\singlespacing
\renewcommand{\pagedeclaration}[1]{\mbox{}\hfill~#1} %dotfill
\renewcommand{\nomgroup}[1]{%
    %\ifthenelse{\equal{#1}{R}}{%
    %\item[LAMBANG\rule{0pt}{7ex} ]}{%
    %\ifthenelse{\equal{#1}{G}}{\item[SINGKATAN]}{}}%
    }%
\renewcommand\nompreamble{%
    \mbox{}\hrulefill~\\
    \mbox{}\hfill Pemakaian\\
    LAMBANG\hspace*{\fill} Keterangan \hfill pertama kali\\
%    Singkatan/ \hfill pertama kali\\
  %  Lambang\hspace*{3.75em} \mbox{}\hfill pada halaman\\
     \mbox{}\hfill pada halaman\\ % 
     \mbox{}\hrulefill~\\}
\makenomenclature
\newcommand{\singkatan}[3]{\nomenclature[g#1 ]{#2}{#3}}
\newcommand{\lambang}[3]{\nomenclature[r#1 ]{#2}{#3}}
%\newcommand{\DaftarSingkatanLambang}{%-------------------------
\newcommand{\DaftarLambang}{%-------------------------
    \newpage
    \singlespacing
%\addcontentsline{toc}{chapter}{DAFTAR SINGKATAN DAN LAMBANG}
    \addcontentsline{toc}{chapter}{DAFTAR LAMBANG}
    \singlespacing
    {\setlength{\parskip}{0.5ex}
    \printnomenclature[7.5em]
   % \printnomenclature[4.5em]
\singlespacing}}

%%==============================================================================
%==============================================================================
\newcommand\MulaiIsiDisertasi{% 
    \label{halakhirR}
    \addtocontents{toc}{\protect{\vspace*{1ex}}}
    \clearpage
    \onehalfspacing
    \pagenumbering{arabic}
    \setcounter{page}{1}
}
\newenvironment{Lampiran}{%-----------------------------------
    \newpage
 \addcontentsline{toc}{chapter}{LAMPIRAN}
\begin{mtchideinmaintoc}
    \appendix
    \part{Lampiran}
    %\parttoc
    }{%
    \end{mtchideinmaintoc}
    }

\renewcommand\part{%
  \if@openright
    \cleardoublepage
  \else
    \clearpage
  \fi
  \thispagestyle{empty}%------
  \if@twocolumn
    \onecolumn
    \@tempswatrue
  \else
    \@tempswafalse
  \fi
  \null\vfil
  \secdef\@part\@spart}

\def\@part[#1]#2{%
    \ifnum \c@secnumdepth >-2\relax
      \refstepcounter{part}%
    \fi
    \markboth{}{}%
    {\centering
     \interlinepenalty \@M
     \normalfont
     \Huge \bfseries \MakeUppercase{#2}\par}%
    \@endpart}
\renewcommand\chapter{\if@openright\cleardoublepage\else\clearpage\fi
                    \thispagestyle{plain}%
                    \global\@topnum\z@
                    \@afterindentfalse
                    \secdef\@chapter\@schapter}
\gdef\@chapter[#1]#2{\ifnum \c@secnumdepth >\m@ne
                       \if@mainmatter
                         \refstepcounter{chapter}%
                         \typeout{\@chapapp\space\thechapter.}%
                         \addcontentsline{toc}{chapter}%
                                   {\protect\numberline{\@chapapp\space\thechapter}#1}%
                       \else
                         \addcontentsline{toc}{chapter}{\@chapapp\space#1}%
                       \fi
                    \else
                      \addcontentsline{toc}{chapter}{#1}%
                    \fi
                    \chaptermark{#1}%
                    \addtocontents{lof}{\protect\addvspace{0\p@}}%{10\p@}}
                    \addtocontents{lot}{\protect\addvspace{0\p@}}%{10\p@}}
                    \if@twocolumn
                      \@topnewpage[\@makechapterhead{#2}]%
                    \else
                      \@makechapterhead{#2}%
                      \@afterheading
                    \fi}
\gdef\@makechapterhead#1{%
%  \vspace*{5\p@}%                                   POSISI BAB
  {\parindent \z@ \centering\normalfont
    \ifnum \c@secnumdepth >\m@ne
      \if@mainmatter
        \large\bfseries \@chapapp\space \thechapter\hskip 1em
      %\fi
    \fi
    \large\bfseries #1\par\nobreak
    \vskip 24\p@    %40\p@
  }}
\gdef\@schapter#1{\@makeschapterhead{#1}%
                 \@afterheading
                 }
\gdef\@makeschapterhead#1{%
%  \vspace*{5\p@}%                                 POSISI DAFTAR ISI, DAFTAR GAMBAR, DAFTAR TABEL, DAFTAR LAMBANG
  {\parindent \z@ \centering
    \normalfont
    \interlinepenalty\@M
    \large\bfseries  #1\par\nobreak
    \vskip 30\p@   %40
}}
\renewcommand\section{\@startsection {section}{1}{\z@}%
                                   {-1.5ex \@plus -1ex \@minus -.2ex}%
                                 %  {.01ex \@plus.2ex}%
                                 {1sp \@minus 0ex\nointerlineskip\vspace
                                 {-\lineskip}}
                                   {\normalfont\large\bfseries}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                     {-1.5ex\@plus -1ex \@minus -.2ex}%
                                     %{.01ex \@plus .2ex}%
                                     {1sp \@minus 0ex\nointerlineskip\vspace
                                 {-\lineskip}}
                                 {\normalfont\normalsize\bfseries}}
\renewcommand\subsubsection{\@startsection{subsubsection}{3}{\z@}%
                                     {-.25ex\@plus -1ex \@minus -.2ex}%
                                 %    {.01ex \@plus.2ex}%
                                  {1sp \@minus 0ex\nointerlineskip\vspace
                                 {-\lineskip}}
                                    {\normalfont\normalsize\bfseries}}
\renewcommand\paragraph{\@startsection{paragraph}{4}{\z@}%
                                    {.25ex \@plus1ex \@minus.2ex}%
                                    {-1.5em}%
                                    {\normalfont\normalsize\bfseries}}
\renewcommand\subparagraph{\@startsection{subparagraph}{5}{\parindent}%
                                    {.25ex \@plus1ex \@minus .2ex}%
                                    {0.1ex \@plus 0ex \@minus 1ex}%
                                    {-1em}%
                                    {\normalfont\normalsize\bfseries}}

\renewcommand \thefigure
     {\ifnum \c@chapter>\z@ \figurename\ \thechapter.\fi \@arabic\c@figure}
\def\fnum@figure{\nobreakspace\thefigure}  \captionsetup{labelsep = quad}


\renewcommand \thetable
     {\ifnum \c@chapter>\z@ \tablename\ \thechapter.\fi \@arabic\c@table}
\def\fnum@table{\nobreakspace\thetable}  \captionsetup{labelsep = quad}

\renewcommand\@dotsep{2}                                               %Jarak antar titik
\renewcommand\tableofcontents{%
      \@restonecolfalse
    \chapter*{\contentsname
        \@mkboth{}{}}%
    \@starttoc{toc}%
    }
\renewcommand*\l@chapter[2]{%
  \ifnum \c@tocdepth >\m@ne
    \addpenalty{-\@highpenalty}%
    \vskip 0.5em \@plus\p@
    \setlength\@tempdima{4em}%
    \begingroup

      \parindent \z@ \rightskip \@pnumwidth
      \parfillskip -\@pnumwidth
      \leavevmode %\bfseries
      \advance\leftskip\@tempdima
      \hskip -\leftskip
      #1\nobreak\dotfill \nobreak\hb@xt@\@pnumwidth{\hss #2}\par
      %#1\nobreak\hfil \nobreak\hb@xt@\@pnumwidth{\hss #2}\par
      \penalty\@highpenalty
    \endgroup
  \fi}
                                                                        %Jarak nomor bab ke kata pertama

\renewcommand*\l@chapter{\@dottedtocline{1}{0em}{4em}}  %agar daftar isi rapat
\renewcommand*\l@section{\@dottedtocline{1}{4em}{2.75em}}
\renewcommand*\l@subsection{\@dottedtocline{2}{6.85em}{3.2em}}
\renewcommand*\l@subsubsection{\@dottedtocline{3}{8.0em}{4.1em}}
\renewcommand*\l@paragraph{\@dottedtocline{4}{10em}{5em}}
\renewcommand*\l@subparagraph{\@dottedtocline{5}{12em}{6em}}
\RequirePackage{makeidx}
\makeindex
\newcommand{\TulisIndeks}{%
    \newpage
    %\small
    \singlespacing
    \addtocontents{toc}{\protect{\vspace*{1ex}}}
    \addcontentsline{toc}{chapter}{INDEKS}
    \printindex
}

%%%------------- PENYESUAIAN ISTILAH ---------------------------
\renewcommand\contentsname{\vskip -1.2cm{DAFTAR ISI}}
%\renewcommand\listappendixname{DAFTAR LAMPIRAN}
\renewcommand\listfigurename{\vskip -1.2cm{DAFTAR GAMBAR}}
\renewcommand\listtablename{\vskip -1.2cm{DAFTAR TABEL}}
\renewcommand\bibname{\vskip -1.2cm{DAFTAR PUSTAKA}}
\renewcommand\indexname{INDEKS}
\renewcommand\appendixname{Lampiran}
\renewcommand\figurename{Gambar}
\renewcommand\tablename{Tabel}
\renewcommand\chaptername{Bab}
\renewcommand{\seename}{\textit{lihat:}}%-------untuk indeks
\renewcommand{\proofname}{{\textbf{Bukti.}}}%---bukti teorema dlsb


%%%-----------setting perujukan dan daftar pustaka----------------
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Pengaturan penulisan daftar pustaka ---------------------------------------------%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage[abbr]{itbbib}
\citationstyle{itbbib}
\renewcommand{\harvardand}{dan}
\newcommand\DaftarPustaka[1]{%
    \clearpage
    \singlespacing
    \setlength{\parskip}{1.5pt} 
    \addcontentsline{toc}{chapter}{DAFTAR PUSTAKA}
    \bibliographystyle{itbbib}
    \bibliography{#1}
}%%%--------------------------------------------------------------
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Rekapitulasi Halaman ------------------------------------------------------------%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage{totpages}%------hanya untuk rekap; bisa dihilangkan
\RequirePackage{datetime}
\newcommand\rekap{%
    \newpage
    \setcounter{page}{\value{page}-1}\label{halakhirA}
    \thispagestyle{empty}
    \null
    \par
    \dotfill\par
    \textbf{Info cetak .....}\par
    Revisi/cetak terakhir: \today, pukul \currenttime \par
    Nomor halaman: i--\pageref{halakhirR},\quad%
                   1--\pageref{halakhirA} \qquad
    Total: \theTotPages\ halaman\par
   \dotfill\par
}
\AtEndDocument{\rekap}%------akhir rekap-----------

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Akhir Rekapitulasi Halaman ------------------------------------------------------------%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\def\today{\number\day\space\ifcase\month\or
 Januari\or Februari\or Maret\or April\or Mei\or Juni\or
 Juli\or Agustus\or September\or Oktober\or November\or Desember\fi
 \space \number\year}

    \setlength\columnsep{10\p@}
    \setlength\columnseprule{0\p@}
    \lefthyphenmin=5
    \righthyphenmin=5
    \pagestyle{plain}
    \pagenumbering{arabic}
    \belowcaptionskip=1ex
    \sloppy
    \onehalfspacing
    %\setlength{\parskip}{1em}
%
%-------menyesuaikan paragraf-----------------------------
\parskip=0.65\baselineskip \advance\parskip by 0pt plus 2pt
\parindent=\z@
   \parsep = \parskip
   %\itemsep = \z@ % add nothing to \parskip between items
   %\topsep = \z@ % add nothing to \parskip before first item

\def\@listI{\leftmargin\leftmargini
   \topsep\z@ \parsep\parskip \itemsep\z@}
\let\@listi\@listI
\@listi

\def\@listii{\leftmargin\leftmarginii
   \labelwidth\leftmarginii\advance\labelwidth-\labelsep
   \topsep\z@ \parsep\parskip \itemsep\z@}
\def\@listiii{\leftmargin\leftmarginiii
    \labelwidth\leftmarginiii\advance\labelwidth-\labelsep
    \topsep\z@ \parsep\parskip \itemsep\z@}
\partopsep=\z@

\@ifundefined{CheckCommand}{}{%
  \CheckCommand*{\@starttoc}[1]{%
    \begingroup
      \makeatletter
      \@input{\jobname.#1}%
      \if@filesw
        \expandafter\newwrite\csname tf@#1\endcsname
        \immediate\openout \csname tf@#1\endcsname \jobname.#1\relax
      \fi
      \@nobreakfalse
    \endgroup}}

\renewcommand*{\@starttoc}[1]{%
  \begingroup
    \makeatletter
    \parskip\z@
    \@input{\jobname.#1}%
    \if@filesw
      \expandafter\newwrite\csname tf@#1\endcsname
      \immediate\openout \csname tf@#1\endcsname \jobname.#1\relax
    \fi
    \@nobreakfalse
  \endgroup
}
\endinput

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%  End of 'disertasi.cls'.                                                         %%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

