%%% File `ringkasan.cls' ditujukan untuk menulis ringkasan disertasi
%%% menggunakan LaTeX untuk program Doktor di Institut Teknologi Bandung,
%%% berdasarkan Pedoman Penulisan Ringkasan Disertasi ITB Tahun 2008.
%%%
%%% Kelas utama yang digunakan adalah `article.cls', dan dengan
%%% demikian semua perintah (untuk penyesuaian) yang berlaku
%%% di kelas `article', bila perlu, masih dapat digunakan. 
%%% Namun demikian, kelas `ringkasan.cls' hanya dirancang untuk digunakan
%%% dengan sectioning '\section' dan `\subsection', tidak untuk yang lain.
%%%
%%% Any comments, suggestions, additions, corrections, modifications
%%% to this file are very welcome.
%%% We rely on your feedback for improving this tool.
%%% <yunusm@matematika.its.ac.id>

\ProvidesClass{ringkasan}[08/08/08 v1.01]
\NeedsTeXFormat{LaTeX2e}
\LoadClass[a5paper,10pt,twoside,final]{article}
\RequirePackage{calc}
\RequirePackage{nohyperref}
\RequirePackage[hang]{caption}
\RequirePackage{minitoc}
\usepackage[labelsep=space]{caption}  
\usepackage{titlecaps}

%----------------------------------------------------------
\DeclareRobustCommand{\Judul}[1]{%
    \newcommand{\@judul}{#1}%
    \title{\@judul}}%
\DeclareRobustCommand{\Nama}[1]{%
   \newcommand{\@nama}{#1}%
   \author{\@nama}}%
\DeclareRobustCommand{\Nim}[1]{%
   \DeclareRobustCommand{\@nim}{#1}}%
\newcommand\@progstudi{Program Studi Matematika}
\DeclareRobustCommand\ProgStudi[1]{%
   \renewcommand\@progstudi{#1}}%
\newcommand\@tahun{2008}
\DeclareRobustCommand\Tahun[1]{%
   \renewcommand\@tahun{#1}}%

 \newcommand\@promotor{} 
 \newcommand\@kopromsatu{} 
 \newcommand\@kopromdua{} 
\DeclareRobustCommand\Promotor[3]{% 
   \renewcommand{\@promotor}{#1}%
   \renewcommand{\@kopromsatu}{#2}%
   \renewcommand{\@kopromdua}{#3}}%
\newcommand\@tanggal{\today}
\DeclareRobustCommand\Tanggal[1]{%
   \renewcommand\@tanggal{#1}}%

%%%----atur spasi -----------------------------------------------------
\newcommand{\displayskipstretch}{\baselinestretch}

\newcommand{\setstretch}[1]{%
  \def\baselinestretch{#1}%
  \@currsize
}

\newcommand{\SetSinglespace}[1]{%
  \def\setspace@singlespace{#1}%
}
\SetSinglespace{1}
\newcommand{\singlespacing}{%
  \setstretch {\setspace@singlespace}%
  \vskip \baselineskip  %
}
\newcommand{\onehalfspacing}{%
  \setstretch{1.25}%  default
  \ifcase \@ptsize \relax % 10pt
    %\setstretch {1.44}%
    \setstretch {1.3}%
  \or % 11pt
    %\setstretch {1.423}%
    \setstretch {1.275}%
  \or % 12pt
    %\setstretch {1.441}%
    \setstretch {1.31}%
  \fi
}

\def\@setsize#1#2#3#4{%
  \@nomath#1%
  \let\@currsize#1%
  \baselineskip #2%
  \baselineskip \baselinestretch\baselineskip
  \parskip \baselinestretch\parskip
  \setbox\strutbox \hbox{%
    \vrule height.7\baselineskip
           depth.3\baselineskip
           width\z@}%
  \skip\footins \baselinestretch\skip\footins
  \normalbaselineskip\baselineskip#3#4}

\let\latex@xfloat=\@xfloat
\def\@xfloat #1[#2]{%
  \latex@xfloat #1[#2]%
  \def\baselinestretch{\setspace@singlespace}%
  \normalsize
}

\long\def\@footnotetext#1{%
  \insert\footins{%
    \def\baselinestretch {\setspace@singlespace}%
    \reset@font\footnotesize
    \interlinepenalty\interfootnotelinepenalty
    \splittopskip\footnotesep
    \splitmaxdepth \dp\strutbox \floatingpenalty \@MM
    \hsize\columnwidth
    \@parboxrestore
    \protected@edef\@currentlabel{%
      \csname p@footnote\endcsname\@thefnmark
    }%
    \color@begingroup
      \@makefntext{%
        \rule\z@\footnotesep\ignorespaces#1\@finalstrut\strutbox}%
    \color@endgroup}}
\everydisplay\expandafter{%
  \the\everydisplay
  \abovedisplayskip \displayskipstretch\abovedisplayskip
  \belowdisplayskip \displayskipstretch\belowdisplayskip
  \abovedisplayshortskip \displayskipstretch\abovedisplayshortskip
  \belowdisplayshortskip \displayskipstretch\belowdisplayshortskip
}

\newcommand\HalamanSampul{%---------------------------
  \null
  \pagenumbering{arabic}
  \pagestyle{empty}
  \begin{center}
     {\LARGE\bfseries\@judul\par}
     \vfill
     {\Large RINGKASAN DISERTASI}\par
     \vspace*{5ex}
     {\Large\@nama}\\
     {\large NIM:~ \@nim} \\
     (\large\@progstudi)\par
     \vskip 2.5em%
    \includegraphics[height=2.75cm]{LogoITB}\par
    \vskip 2.5em%
    {\Large Institut Teknologi Bandung\par
    \Large\@tahun}
  \end{center}
  \cleardoublepage
}  

\newcommand\HalamanJudul{%---------------------------
  \null
  \vskip 7.5\p@
  \singlespacing
  \begin{center}%
    {\LARGE\bfseries\@judul\par}%
    \vfill
    {\large Disertasi ini dipertahankan pada Sidang Terbuka Komisi Sekolah 
    Pascasarjana sebagai salah satu syarat untuk memperoleh  gelar Doktor
    Institut Teknologi Bandung\par
    }
    \vfill
    {\large \@tanggal}\par
    \vfill\par
    {\Large\@nama}\\
     {\large NIM:~\@nim\\
     (\@progstudi)}\par
    \vfill
    {\Large Promotor\,:~\, \@promotor\\
     Ko-Promotor~1\,:~\, \@kopromsatu\\
     Ko-Promotor~2\,:~\, \@kopromdua\par}
    \vfill
    {\Large Institut Teknologi Bandung\par
    \@tahun} 
  \end{center}
  \cleardoublepage
}

\newcommand{\MulaiIsiRingkasan}{%
  \pagestyle{plain}
  \pagenumbering{arabic}
  \setcounter{page}{3}
  \onehalfspacing
  \begin{center}
     {\Large\bfseries\@judul}\par
     \@nama\\
     NIM:~\@nim\\
     (\@progstudi)\par
  \end{center}
  \vspace*{3ex}
}


\newcommand{\trmkasih}{UCAPAN TERIMAKASIH}
\newenvironment{terimakasih}{%----------------
    \newpage
    \singlespacing
    \begin{center}
        \large\bfseries UCAPAN TERIMA KASIH  %\trmkasih
    \end{center}
    \par
    \vspace*{3ex}
      \setlength{\parskip}{12pt}
      }

%\newcommand{\RiwayatHidup}{%---------------
\newenvironment{riwayathidup}{%----------------------------
 \newpage
    \begin{center}
        \large\bfseries RIWAYAT HIDUP
    \end{center}
    \par
    \vspace*{3ex}
    }

\RequirePackage[hmargin={1.5cm,1.5cm},vmargin={1.5cm,2cm}]{geometry}
\RequirePackage{graphicx}
\RequirePackage{parskip}
\RequirePackage{amssymb}
\RequirePackage{amsmath}
\RequirePackage{amsthm}
\RequirePackage{amsfonts}
%%---menentukan jenis font yang digunakan--------
\RequirePackage{times}
\RequirePackage{mathrsfs}
\RequirePackage[scaled=.90]{helvet}
%%---mengatur jarak dalam list -----------
\RequirePackage{enumitem}
\setlist{labelindent=\parindent,itemsep=-1ex,%
         leftmargin=*,topsep=-1ex}         
%%---atur judul sectioning-------
                              
\setcounter{secnumdepth}{0}                                   

\renewcommand\section{\@startsection {section}{1}{\z@}%
                                   {-2ex \@plus -1ex \@minus -.2ex}%
                                   {.1ex \@plus.1ex}%
                                   {\normalfont\normalsize\bfseries}} %\MakeUppercase}}
\renewcommand\subsection{\@startsection{subsection}{2}{\z@}%
                                     {-1ex\@plus -1ex \@minus -.2ex}%
                                     {.1ex \@plus .1ex}%
                                     {\normalfont\normalsize\bfseries}}


\def\today{\number\day\space\ifcase\month\or
 Januari\or Februari\or Maret\or April\or Mei\or Juni\or
 Juli\or Agustus\or September\or Oktober\or November\or Desember\fi
 \space \number\year}

    \setlength\columnsep{10\p@}
    \setlength\columnseprule{0\p@}
    \lefthyphenmin=5
    \righthyphenmin=5
    \pagestyle{plain}
    \pagenumbering{arabic}
    \belowcaptionskip=1ex
    \sloppy
    \onehalfspacing
    %\setlength{\parskip}{1em}
%

%%%-----------setting perujukan dan daftar pustaka----------------
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%% Pengaturan penulisan daftar pustaka ---------------------------------------------%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\RequirePackage[abbr]{itbbib}
\citationstyle{itbbib}
\renewcommand{\harvardand}{dan}
\newcommand\DaftarPustaka[1]{%
    \clearpage
    \singlespacing
    \setlength{\parskip}{1.5pt} 
    \addcontentsline{toc}{chapter}{DAFTAR PUSTAKA}
    \bibliographystyle{itbbib}
    \bibliography{#1}
    
}


%%%--------------------------------------------------------------

%-------menyesuaikan paragraf-----------------------------
\parskip=0.65\baselineskip \advance\parskip by 0pt plus 2pt
\parindent=\z@
   \parsep = \parskip
   %\itemsep = \z@ % add nothing to \parskip between items
   %\topsep = \z@ % add nothing to \parskip before first item

\def\@listI{\leftmargin\leftmargini
   \topsep\z@ \parsep\parskip \itemsep\z@}
\let\@listi\@listI
\@listi

\def\@listii{\leftmargin\leftmarginii
   \labelwidth\leftmarginii\advance\labelwidth-\labelsep
   \topsep\z@ \parsep\parskip \itemsep\z@}
\def\@listiii{\leftmargin\leftmarginiii
    \labelwidth\leftmarginiii\advance\labelwidth-\labelsep
    \topsep\z@ \parsep\parskip \itemsep\z@}
\partopsep=\z@

\@ifundefined{CheckCommand}{}{%
  \CheckCommand*{\@starttoc}[1]{%
    \begingroup
      \makeatletter
      \@input{\jobname.#1}%
      \if@filesw
        \expandafter\newwrite\csname tf@#1\endcsname
        \immediate\openout \csname tf@#1\endcsname \jobname.#1\relax
      \fi
      \@nobreakfalse
    \endgroup}}

\renewcommand*{\@starttoc}[1]{%
  \begingroup
    \makeatletter
    \parskip\z@
    \@input{\jobname.#1}%
    \if@filesw
      \expandafter\newwrite\csname tf@#1\endcsname
      \immediate\openout \csname tf@#1\endcsname \jobname.#1\relax
    \fi
    \@nobreakfalse
  \endgroup
}
\endinput
%%
%% end of file `ringkasan.cls'.
